summaryrefslogtreecommitdiffstats
path: root/Python/executor_cases.c.h
diff options
context:
space:
mode:
authorGuido van Rossum <guido@python.org>2023-09-11 22:39:19 (GMT)
committerGitHub <noreply@github.com>2023-09-11 22:39:19 (GMT)
commitfbaf77eb9bd1e6812ebf984d32b29b025cc037d6 (patch)
treedbe770374dcdb9d414bc9ff4bc9937b194039032 /Python/executor_cases.c.h
parent1ee50e2a78f644d81d341a08562073ad169d8cc7 (diff)
downloadcpython-fbaf77eb9bd1e6812ebf984d32b29b025cc037d6.zip
cpython-fbaf77eb9bd1e6812ebf984d32b29b025cc037d6.tar.gz
cpython-fbaf77eb9bd1e6812ebf984d32b29b025cc037d6.tar.bz2
gh-109214: Rename SAVE_IP to _SET_IP, and similar (#109285)
* Rename SAVE_IP to _SET_IP * Rename EXIT_TRACE to _EXIT_TRACE * Rename SAVE_CURRENT_IP to _SAVE_CURRENT_IP * Rename INSERT to _INSERT (This is for Ken Jin's abstract interpreter) * Rename IS_NONE to _IS_NONE * Rename JUMP_TO_TOP to _JUMP_TO_TOP
Diffstat (limited to 'Python/executor_cases.c.h')
-rw-r--r--Python/executor_cases.c.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/Python/executor_cases.c.h b/Python/executor_cases.c.h
index 918991d..a4d8130 100644
--- a/Python/executor_cases.c.h
+++ b/Python/executor_cases.c.h
@@ -1902,7 +1902,7 @@
break;
}
- case IS_NONE: {
+ case _IS_NONE: {
PyObject *value;
PyObject *b;
value = stack_pointer[-1];
@@ -2887,29 +2887,29 @@
break;
}
- case JUMP_TO_TOP: {
+ case _JUMP_TO_TOP: {
pc = 0;
CHECK_EVAL_BREAKER();
break;
}
- case SAVE_IP: {
+ case _SET_IP: {
frame->prev_instr = ip_offset + oparg;
break;
}
- case SAVE_CURRENT_IP: {
+ case _SAVE_CURRENT_IP: {
#if TIER_ONE
frame->prev_instr = next_instr - 1;
#endif
#if TIER_TWO
// Relies on a preceding SAVE_IP
frame->prev_instr--;
#endif
break;
}
- case EXIT_TRACE: {
+ case _EXIT_TRACE: {
frame->prev_instr--; // Back up to just before destination
_PyFrame_SetStackPointer(frame, stack_pointer);
Py_DECREF(self);
@@ -2917,7 +2917,7 @@
break;
}
- case INSERT: {
+ case _INSERT: {
PyObject *top;
top = stack_pointer[-1];
// Inserts TOS at position specified by oparg;
@@ -2887,29 +2887,29 @@
#endif
#if TIER_TWO
- // Relies on a preceding SAVE_IP
+ // Relies on a preceding _SET_IP
frame->prev_instr--;
#endif